@@ -3,31 +3,34 @@ package Function::Return;
 use v5.14.0;
 use warnings;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use attributes ();
 use Sub::Util ();
 use Sub::Info ();
 use Scalar::Util ();
 use Scope::Upper ();
+use B::Hooks::EndOfScope;
 use Function::Parameters;
 
-our $DEFAULT_ATTR_NAME = 'Return';
+my $ATTR_NAME = 'Return';
 
-my %IMPORT;
+my %NO_CHECK;
 sub import {
     my $pkg = caller;
     my $class = shift;
     my %args = @_;
 
     $pkg = $args{pkg} ? $args{pkg} : $pkg;
-
-    $IMPORT{name} = exists $args{name} ? $args{name} : $DEFAULT_ATTR_NAME;
-    $IMPORT{no_check} = exists $args{no_check} ? $args{no_check} : !!0;
+    $NO_CHECK{$pkg} = exists $args{no_check} ? !!$args{no_check} : !!0;
 
     no strict qw(refs);
     *{"${pkg}::FETCH_CODE_ATTRIBUTES"} = \&_FETCH_CODE_ATTRIBUTES;
     *{"${pkg}::MODIFY_CODE_ATTRIBUTES"} = \&_MODIFY_CODE_ATTRIBUTES;
+
+    on_scope_end {
+        _check_sub();
+    }
 }
 
 my %ATTR;
@@ -52,20 +55,23 @@ sub _MODIFY_CODE_ATTRIBUTES {
             types => $types,
         }
     }
-    $ATTR{$sub} = [ grep { !_attr_re() } @attrs ];
+    $ATTR{$sub} = [ grep { $_ !~ _attr_re() } @attrs ];
     return;
 }
 
 sub _attr_re {
     return qr!
         ^
-        $IMPORT{name}
+        $ATTR_NAME
         \((.*?)\)
         $
     !x;
 }
 
-sub no_check { $IMPORT{no_check} }
+sub no_check {
+    my $pkg = shift;
+    $NO_CHECK{$pkg}
+}
 
 sub _croak {
     my (undef, $file, $line) = caller 1;
@@ -170,11 +176,11 @@ sub _register_return_info {
     $metadata{$key} = $info;
 }
 
-sub CHECK {
+sub _check_sub {
     for my $decl (@DECLARATIONS) {
         my ($pkg, $sub, $types)  = @$decl{qw(pkg sub types)};
 
-        if (no_check) {
+        if (no_check($pkg)) {
             _register_return_info($sub, $types);
             next;
         }
@@ -240,14 +246,6 @@ This module supports all perl versions starting from v5.14.
 
 =head2 IMPORT OPTIONS
 
-=head3 name
-
-you can change the C<< :Return >> attribute to your own name:
-
-    use Function::Return name => 'MyReturn';
-
-    sub foo :MyReturn(Str) { }
-
 =head3 no_check
 
 you can switch off type check:
